==> camel-k-model-v1-5.11.1-sources.jar: annotations/io/fabric8/camelk/v1/CapabilityFluentImpl.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CapabilityFluentImpl<A extends io.fabric8.camelk.v1.CapabilityFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.camelk.v1.CapabilityFluent<A>{
  public CapabilityFluentImpl() {
  }
  public CapabilityFluentImpl(io.fabric8.camelk.v1.Capability instance) {
    this.withDependencies(instance.getDependencies()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private java.util.List<io.fabric8.camelk.v1.MavenArtifactBuilder> dependencies;
  private java.util.Map<java.lang.String,java.lang.String> metadata;
  public A addToDependencies(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(index >= 0 ? index : _visitables.get("dependencies").size(), builder);this.dependencies.add(index >= 0 ? index : dependencies.size(), builder); return (A)this;
  }
  public A setToDependencies(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);
    if (index < 0 || index >= _visitables.get("dependencies").size()) { _visitables.get("dependencies").add(builder); } else { _visitables.get("dependencies").set(index, builder);}
    if (index < 0 || index >= dependencies.size()) { dependencies.add(builder); } else { dependencies.set(index, builder);}
     return (A)this;
  }
  public A addToDependencies(io.fabric8.camelk.v1.MavenArtifact... items) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(builder);this.dependencies.add(builder);} return (A)this;
  }
  public A addAllToDependencies(java.util.Collection<io.fabric8.camelk.v1.MavenArtifact> items) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(builder);this.dependencies.add(builder);} return (A)this;
  }
  public A removeFromDependencies(io.fabric8.camelk.v1.MavenArtifact... items) {
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").remove(builder);if (this.dependencies != null) {this.dependencies.remove(builder);}} return (A)this;
  }
  public A removeAllFromDependencies(java.util.Collection<io.fabric8.camelk.v1.MavenArtifact> items) {
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").remove(builder);if (this.dependencies != null) {this.dependencies.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromDependencies(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    if (dependencies == null) return (A) this;
    final Iterator<io.fabric8.camelk.v1.MavenArtifactBuilder> each = dependencies.iterator();
    final List visitables = _visitables.get("dependencies");
    while (each.hasNext()) {
      io.fabric8.camelk.v1.MavenArtifactBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildDependencies instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.camelk.v1.MavenArtifact> getDependencies() {
    return build(dependencies);
  }
  public java.util.List<io.fabric8.camelk.v1.MavenArtifact> buildDependencies() {
    return build(dependencies);
  }
  public io.fabric8.camelk.v1.MavenArtifact buildDependency(java.lang.Integer index) {
    return this.dependencies.get(index).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildFirstDependency() {
    return this.dependencies.get(0).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildLastDependency() {
    return this.dependencies.get(dependencies.size() - 1).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    for (io.fabric8.camelk.v1.MavenArtifactBuilder item: dependencies) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    for (io.fabric8.camelk.v1.MavenArtifactBuilder item: dependencies) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDependencies(java.util.List<io.fabric8.camelk.v1.MavenArtifact> dependencies) {
    if (this.dependencies != null) { _visitables.get("dependencies").removeAll(this.dependencies);}
    if (dependencies != null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>(); for (io.fabric8.camelk.v1.MavenArtifact item : dependencies){this.addToDependencies(item);}} else { this.dependencies = null;} return (A) this;
  }
  public A withDependencies(io.fabric8.camelk.v1.MavenArtifact... dependencies) {
    if (this.dependencies != null) {this.dependencies.clear();}
    if (dependencies != null) {for (io.fabric8.camelk.v1.MavenArtifact item :dependencies){ this.addToDependencies(item);}} return (A) this;
  }
  public java.lang.Boolean hasDependencies() {
    return dependencies != null && !dependencies.isEmpty();
  }
  public A addNewDependency(java.lang.String artifactId,java.lang.String groupId,java.lang.String version) {
    return (A)addToDependencies(new MavenArtifact(artifactId, groupId, version));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> addNewDependency() {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl();
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> addNewDependencyLike(io.fabric8.camelk.v1.MavenArtifact item) {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl(-1, item);
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> setNewDependencyLike(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl(index, item);
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editDependency(java.lang.Integer index) {
    if (dependencies.size() <= index) throw new RuntimeException("Can't edit dependencies. Index exceeds size.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editFirstDependency() {
    if (dependencies.size() == 0) throw new RuntimeException("Can't edit first dependencies. The list is empty.");
    return setNewDependencyLike(0, buildDependency(0));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editLastDependency() {
    int index = dependencies.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last dependencies. The list is empty.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    int index = -1;
    for (int i=0;i<dependencies.size();i++) { 
    if (predicate.test(dependencies.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching dependencies. No match found.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public A addToMetadata(java.lang.String key,java.lang.String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null && map != null) { this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(java.lang.String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(java.util.Map<java.lang.String,java.lang.String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CapabilityFluentImpl that = (CapabilityFluentImpl) o;
    if (dependencies != null ? !dependencies.equals(that.dependencies) :that.dependencies != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dependencies,  metadata,  super.hashCode());
  }
  public class DependenciesNestedImpl<N> extends io.fabric8.camelk.v1.MavenArtifactFluentImpl<io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<N>> implements io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DependenciesNestedImpl(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
      this.index = index;
      this.builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(this, item);
    }
    DependenciesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(this);
    }
    io.fabric8.camelk.v1.MavenArtifactBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) CapabilityFluentImpl.this.setToDependencies(index,builder.build());
    }
    public N endDependency() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-5.12.0-sources.jar: annotations/io/fabric8/camelk/v1/CapabilityFluentImpl.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CapabilityFluentImpl<A extends io.fabric8.camelk.v1.CapabilityFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.camelk.v1.CapabilityFluent<A>{
  public CapabilityFluentImpl() {
  }
  public CapabilityFluentImpl(io.fabric8.camelk.v1.Capability instance) {
    this.withDependencies(instance.getDependencies()); 
    this.withMetadata(instance.getMetadata()); 
  }
  private java.util.List<io.fabric8.camelk.v1.MavenArtifactBuilder> dependencies;
  private java.util.Map<java.lang.String,java.lang.String> metadata;
  public A addToDependencies(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(index >= 0 ? index : _visitables.get("dependencies").size(), builder);this.dependencies.add(index >= 0 ? index : dependencies.size(), builder); return (A)this;
  }
  public A setToDependencies(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);
    if (index < 0 || index >= _visitables.get("dependencies").size()) { _visitables.get("dependencies").add(builder); } else { _visitables.get("dependencies").set(index, builder);}
    if (index < 0 || index >= dependencies.size()) { dependencies.add(builder); } else { dependencies.set(index, builder);}
     return (A)this;
  }
  public A addToDependencies(io.fabric8.camelk.v1.MavenArtifact... items) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(builder);this.dependencies.add(builder);} return (A)this;
  }
  public A addAllToDependencies(java.util.Collection<io.fabric8.camelk.v1.MavenArtifact> items) {
    if (this.dependencies == null) {this.dependencies = new java.util.ArrayList<io.fabric8.camelk.v1.MavenArtifactBuilder>();}
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").add(builder);this.dependencies.add(builder);} return (A)this;
  }
  public A removeFromDependencies(io.fabric8.camelk.v1.MavenArtifact... items) {
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").remove(builder);if (this.dependencies != null) {this.dependencies.remove(builder);}} return (A)this;
  }
  public A removeAllFromDependencies(java.util.Collection<io.fabric8.camelk.v1.MavenArtifact> items) {
    for (io.fabric8.camelk.v1.MavenArtifact item : items) {io.fabric8.camelk.v1.MavenArtifactBuilder builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(item);_visitables.get("dependencies").remove(builder);if (this.dependencies != null) {this.dependencies.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromDependencies(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    if (dependencies == null) return (A) this;
    final Iterator<io.fabric8.camelk.v1.MavenArtifactBuilder> each = dependencies.iterator();
    final List visitables = _visitables.get("dependencies");
    while (each.hasNext()) {
      io.fabric8.camelk.v1.MavenArtifactBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildDependencies instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.camelk.v1.MavenArtifact> getDependencies() {
    return build(dependencies);
  }
  public java.util.List<io.fabric8.camelk.v1.MavenArtifact> buildDependencies() {
    return build(dependencies);
  }
  public io.fabric8.camelk.v1.MavenArtifact buildDependency(java.lang.Integer index) {
    return this.dependencies.get(index).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildFirstDependency() {
    return this.dependencies.get(0).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildLastDependency() {
    return this.dependencies.get(dependencies.size() - 1).build();
  }
  public io.fabric8.camelk.v1.MavenArtifact buildMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    for (io.fabric8.camelk.v1.MavenArtifactBuilder item: dependencies) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    for (io.fabric8.camelk.v1.MavenArtifactBuilder item: dependencies) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDependencies(java.util.List<io.fabric8.camelk.v1.MavenArtifact> dependencies) {
    if (this.dependencies != null) { _visitables.get("dependencies").removeAll(this.dependencies);}
    if (dependencies != null) {this.dependencies = new java.util.ArrayList(); for (io.fabric8.camelk.v1.MavenArtifact item : dependencies){this.addToDependencies(item);}} else { this.dependencies = null;} return (A) this;
  }
  public A withDependencies(io.fabric8.camelk.v1.MavenArtifact... dependencies) {
    if (this.dependencies != null) {this.dependencies.clear();}
    if (dependencies != null) {for (io.fabric8.camelk.v1.MavenArtifact item :dependencies){ this.addToDependencies(item);}} return (A) this;
  }
  public java.lang.Boolean hasDependencies() {
    return dependencies != null && !dependencies.isEmpty();
  }
  public A addNewDependency(java.lang.String artifactId,java.lang.String groupId,java.lang.String version) {
    return (A)addToDependencies(new MavenArtifact(artifactId, groupId, version));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> addNewDependency() {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl();
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> addNewDependencyLike(io.fabric8.camelk.v1.MavenArtifact item) {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl(-1, item);
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> setNewDependencyLike(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
    return new io.fabric8.camelk.v1.CapabilityFluentImpl.DependenciesNestedImpl(index, item);
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editDependency(java.lang.Integer index) {
    if (dependencies.size() <= index) throw new RuntimeException("Can't edit dependencies. Index exceeds size.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editFirstDependency() {
    if (dependencies.size() == 0) throw new RuntimeException("Can't edit first dependencies. The list is empty.");
    return setNewDependencyLike(0, buildDependency(0));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editLastDependency() {
    int index = dependencies.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last dependencies. The list is empty.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<A> editMatchingDependency(java.util.function.Predicate<io.fabric8.camelk.v1.MavenArtifactBuilder> predicate) {
    int index = -1;
    for (int i=0;i<dependencies.size();i++) { 
    if (predicate.test(dependencies.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching dependencies. No match found.");
    return setNewDependencyLike(index, buildDependency(index));
  }
  public A addToMetadata(java.lang.String key,java.lang.String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null && map != null) { this.metadata = new java.util.LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(java.lang.String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(java.util.Map<java.lang.String,java.lang.String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new java.util.LinkedHashMap(metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CapabilityFluentImpl that = (CapabilityFluentImpl) o;
    if (dependencies != null ? !dependencies.equals(that.dependencies) :that.dependencies != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dependencies,  metadata,  super.hashCode());
  }
  public class DependenciesNestedImpl<N> extends io.fabric8.camelk.v1.MavenArtifactFluentImpl<io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<N>> implements io.fabric8.camelk.v1.CapabilityFluent.DependenciesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DependenciesNestedImpl(java.lang.Integer index,io.fabric8.camelk.v1.MavenArtifact item) {
      this.index = index;
      this.builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(this, item);
    }
    DependenciesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.camelk.v1.MavenArtifactBuilder(this);
    }
    io.fabric8.camelk.v1.MavenArtifactBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) CapabilityFluentImpl.this.setToDependencies(index,builder.build());
    }
    public N endDependency() {
      return and();
    }
    
  }
  
}
